Package: libweif:x64-linux@0.2.0

**Host Environment**

- Host: x64-linux
- Compiler: GNU 15.1.1
- CMake Version: 3.31.10
-    vcpkg-tool version: 2025-12-05-d84fb805651077f4ed3a97b61fbad2b513462f8b
    vcpkg-scripts version: ee12231b20 2025-12-12 (4 hours ago)

**To Reproduce**

`vcpkg install `

**Failure logs**

```
Downloading https://api.github.com/repos/matwey/libweif/tarball/0.2.2 -> matwey-libweif-0.2.2.tar.gz
matwey-libweif-0.2.2.tar.gz.649861.part: error: download from https://api.github.com/repos/matwey/libweif/tarball/0.2.2 had an unexpected hash
note: Expected: 7303b1832c44d6a0a07362fb3d52e0e79d4775ee567ff49624c102c036f050cf691b4d25db14f788b7acb9f15d4930a223df93ac0e3d5d8d4251430d1a1f9759
note: Actual  : 5de2c4ef7c3aa115c139e8a2fa9925d0146e2c353a710d58aed48708d7cc1bc58bd96da5adc636533a3933e38701e1dd5ad0ece7841418c01fd739b17e68133c
CMake Error at scripts/cmake/vcpkg_download_distfile.cmake:136 (message):
  Download failed, halting portfile.
Call Stack (most recent call first):
  scripts/cmake/vcpkg_from_github.cmake:120 (vcpkg_download_distfile)
  /home/matwey/lab/pyweif/.overlay-ports/libweif/portfile.cmake:1 (vcpkg_from_github)
  scripts/ports.cmake:206 (include)



```

**Additional context**

<details><summary>vcpkg.json</summary>

```
{
  "dependencies": [
    "boost-compat",
    "libweif"
  ]
}

```
</details>
